==> 1Password-3.4.2.zip: 1Password.app/Contents/Resources/Clues/CreditCardClues.js <==
{
	"type": 
	{ 
		"fields": [ "creditcardtype", "cardtype", "card_type_f", "card_type", "cc_paytype", "cctype", "cctype1", "paymenttype", "Ecom_Payment_Card_Type" ], 
		"+labels": [ "Credit Card Type", "Card Type", "CARD TYPE", "Type of Credit Card", "Kreditkartentyp", "Kreditkartenfirma" ], 
		"values": [ "Visa", "VISA", "Visa Card", "Mastercard", "Discover", "American Express" ], 
		"types": "SR"
	},
	
	"ccnum":
	{
		"fields": [ "card_no", "cn","creditcardnumber", "cardnumber", "ccnum", "cc_num", "cc_number", "ccnumber", "card_number_f", "credit_card_number", "card_number", "newcreditcardnumber", "cardnumber", "cc_card_number1", "1.28.9.5.5.1.0.13.3.1.26.1", "1.28.9.5.5.1.0.13.5.1.26.1", "1.26.9.5.5.1.0.13.5.1.24.3.0", "cardnbr", "creditcard.cardnumber", "cardnoinput", "cds_cc_number", "creditcard:cardnumber", "txtcardnumber", "customer/card/number", "purchaseDetailsForm.cvv2", "layout1:imiddlectl:icardctl:icardnumber", "kortnr", "cc_card_number", "ccn", "Ecom_Payment_Card_Number" ], 
		"+labels": [ "Credit Card Number", "Credit card number", "credit card number", "Card Number", "Card number", "CARD NUMBER", "Card #", "Credit Card #", "Card or account number", "Card or Account Number", "Credit Card No", "CC Number", "Visa #", "MasterCard #", "American Express #", "Card Verification No.",
					"Numéro", 
					"Kreditkarten-Nummer", "Kartennummer", "Kreditkarte", "Kreditkartennummer", 
					"Kreditkort", 
					"Kontokort",
					"Kortnummer"
					], 
		"-labels": [ "Gift Card Number" ],
		"types": "T",
		"minLength": 16
	},
	
	"cardholder":
	{
		"fields": [ "creditcardowner", "cardholder", "cc_name", "card_name_f", "cardname", "newcreditcardname", "cardholdersname", "cc_card_name1", "nameoncard", "txtcardholder", "paymentinfo[cardowner]", "customer/billing/name", "Ecom_Payment_Card_Name" ], 
		"+labels": [ "Credit Card Owner", "Cardholder", "Card holder", "Card Holder", "card holder", "Name on Card", "NAME ON CARD", "Name on card", "Name On Card", "Name of card holder", "Card Holder Name", "Card holder's name on credit card", "Name Printed on Card", "Name on the Card", "Name on Credit Card", "Card Holders Name", "Card holders name", "Cardholder's Name", "Cardholders Name", "cardholder name", "Kreditkarteninhaber", "Karteninhaber", "Name auf der Karte", "Name auf der Kreditkarte", "Navn på kortet" ], 
		"-labels": [ "Payment Amount" ],
		"types": "T",
		"minLength": 15
	},
	
	"expiry_mm":
	{
		"fields": [ "expmonth", "expimonth", "ccmonth", "ccexpmonth", "ccexpiremonth", "expiry_date_f", "newcreditcardmonth", "selexpmonth", "cardmonth", "cc_expdate_month", "ccmo", "expiration_month1", "expirationmonth", "1.28.9.5.5.1.0.13.3.1.28", "creditcard.exp.month", "cc_exp_month", "cds_cc_exp_month", "ccexp", "expirymonth", "cmbmonth", "paymentinfo[thrumonth]", "card_exp_mo", "expmo", "Ecom_Payment_Card_ExpDate_Month" ], 
		"+labels": [ "Expiration Date", "Expiration date", "Credit card expiry date (MM/YYYY)", "Expiry Date", "EXPIRY DATE", "Expires", "Expire fin", "Ablaufmonat" ], 
		"-labels": [ "Issued", "Valid From", "Start Date" ], 
		"values":[ "11", "12 - Dec", "12 - December", "11-November", "Jan", "Oct (10)", "January", "jan", "Январь", "январь", "Januar", "janvier", "janv.", "enero", "gennaio" ],
		"types": "ST",
		"minLength": 2,
		"maxLength": 2
	},
	
	"expiry_yy":
	{
		"fields": [ "expyear", "expiyear", "ccexpyear", "ccexpireyear", "expirationyear", "ccyear", "newcreditcardyear", "selexpyear", "cardyear", "cc_expdate_year", "ccyr", "expiration_year1", "1.28.9.5.5.1.0.13.3.1.30", "creditcard.exp.year" , "cc_exp_year", "cds_cc_exp_year", "expiryyear", "cmbyear", "paymentinfo[thruyear]", "card_exp_yr", "expyr", "Ecom_Payment_Card_ExpDate_Year" ], 
		"+labels": [ "Expiration Year", "/" ], 
		"values": [ "2011", "14" ],
		"-values": [ "2005" ],
		"types": "ST",
		"minLength": 2,
		"maxLength": 4
	},
	
	"validFrom_mm":
	{
		"fields": [ "frommonth", "paymentinfo[frommonth]", "startmonth", "startmo", "Ecom_Payment_Card_ValidFrom_Month" ], 
		"+labels": [ "Date Valid From", "Issued", "Start Date" ], 
		"-labels": [ "Expiration Date", "Expiration date", "Expiry Date", "EXPIRY DATE", "Expires", "Expire fin", "Ablaufmonat" ], 
		"values":[ "11", "12 - Dec", "12 - December", "11-November", "Jan", "Oct (10)", "January", "jan", "Январь", "январь", "Januar", "janvier", "janv.", "enero", "gennaio", "DEZ" ],
		"types": "ST",
		"minLength": 2,
		"maxLength": 2
	},
	
	"validFrom_yy":
	{
		"fields": [ "fromyear", "paymentinfo[fromyear]", "startyear", "startyr", "Ecom_Payment_Card_ValidFrom_Year" ], 
		"+labels": [ "From Year", "Issued Year" ], 
		"values": [ "2006" ],
		"types": "ST",
		"minLength": 2,
		"maxLength": 4
	},
	
	"cvv": 
	{
		"fields": [ "cvv2", "ccv2", "cvc2", "cvv", "ccv", "cvs", "csc", "cccvv2", "verify_credit_card", "cvv2_number", "cccvc", "ccvnc", "cc_security_code1", "1.28.9.5.5.1.0.13.3.1.32.1", "1.28.9.5.5.1.0.13.5.1.32.1", "1.26.9.5.5.1.0.13.5.1.30.1", "securitycodefield", "ccvernbr", "creditcard.cvv", "cardcvv", "ccsec", "creditcard:cvn", "txtcvc2", "cccsc", "customer/card/securityid", "cccid", "creditcard.cvn", "kontrol", "cardverificationcode", "cardcvm", "ccode", "card_verification", "Ecom_Payment_Card_Verification", "credit_cvv", "cardsec" ], 
		"+labels": [ "Credit Card Security ID", "CVV2 Number", "Security Code", "Security code", "security code", "Credit card security code", "Security Digits", "CVS Code", "CVV Code", "CVV", "Card ID Number", "Verification Code", "Card Verification Code", "Enter security code", "Card Verification", "Card Identification Number", "CVV2", "V-Code", "CVC", "CSC", "Card Verification Number", "CID Number", "CID", "Cryptogramme de sécurité", "Cvc", "Checksumme", "Verifikationskode", "Sicherheitskode", "kontrolciffer", "Kontrolcifre", "Card Security Value", "Card code", "Signature Panel Code", "Card Validation Number", "CVV / Card ID", "Card ID", "CVD Number", "Security Digits", "CVV/CV2" ], 
		"types": "TP",
		"minLength": 3,
		"maxLength": 5
	},
	
	"issuenumber" :
	{
		"fields": [ "paymentinfo[cardissuenumber]", "issue_number_f", "issuenum", "Ecom_Payment_Card_IssueNumber" ],
		"+labels": [ "Issue Number" ],
		"types": "T",
		"minLength": 5,
		"maxLength": 6
	}
}

==> 1Password-3.8.6.zip: 1Password.app/Contents/Resources/Clues/CreditCardClues.js <==
{
	"type": 
	{ 
		"fields": [ "creditcardtype", "cardtype", "card_type_f", "card_type", "cc_paytype", "cctype", "cctype1", "paymenttype", "Ecom_Payment_Card_Type" ], 
		"+labels": [ "Credit Card Type", "Card Type", "CARD TYPE", "Type of Credit Card", "Kreditkartentyp", "Kreditkartenfirma", "Kaarttype" ], 
		"values": [ "Visa", "VISA", "Visa Card", "Mastercard", "Discover", "American Express" ], 
		"types": "SR"
	},
	
	"ccnum":
	{
		"fields": [ "card_no", "cn","creditcardnumber", "cardnumber", "ccnum", "cc_num", "cc_number", "ccnumber", "card_number_f", "credit_card_number", "card_number", "newcreditcardnumber", "cardnumber", "cc_card_number1", "1.28.9.5.5.1.0.13.3.1.26.1", "1.28.9.5.5.1.0.13.5.1.26.1", "1.26.9.5.5.1.0.13.5.1.24.3.0", "cardnbr", "creditcard.cardnumber", "cardnoinput", "cds_cc_number", "creditcard:cardnumber", "txtcardnumber", "customer/card/number", "purchaseDetailsForm.cvv2", "layout1:imiddlectl:icardctl:icardnumber", "kortnr", "cc_card_number", "ccn", "Ecom_Payment_Card_Number", "billing[number]" ], 
		"+labels": [ "Credit Card Number", "Credit card number", "credit card number", "Card Number", "Card number", "CARD NUMBER", "Card #", "Credit Card #", "Card or account number", "Card or Account Number", "Credit Card No", "CC Number", "Visa #", "MasterCard #", "American Express #", "Card Verification No.",
					"Numéro", 
					"Kreditkarten-Nummer", "Kartennummer", "Kreditkarte", "Kreditkartennummer", 
					"Kreditkort", 
					"Kontokort",
					"Kortnummer",
					"Kaartnummer"
					], 
		"-labels": [ "Gift Card Number" ],
		"types": "T",
		"minLength": 16
	},
	
	"cardholder":
	{
		"fields": [ "creditcardowner", "cardholder", "cc_name", "card_name_f", "cardname", "newcreditcardname", "cardholdersname", "cc_card_name1", "nameoncard", "txtcardholder", "paymentinfo[cardowner]", "customer/billing/name", "Ecom_Payment_Card_Name" ], 
		"+labels": [ "Credit Card Owner", "Cardholder", "Card holder", "Card Holder", "card holder", "Name on Card", "NAME ON CARD", "Name on card", "Name On Card", "Name of card holder", "Card Holder Name", "Card holder's name on credit card", "Name Printed on Card", "Name on the Card", "Name on Credit Card", "Card Holders Name", "Card holders name", "Cardholder's Name", "Cardholders Name", "cardholder name", "Kreditkarteninhaber", "Karteninhaber", "Name auf der Karte", "Name auf der Kreditkarte", "Navn på kortet" ], 
		"-labels": [ "Payment Amount" ],
		"types": "T",
		"minLength": 15
	},
	
	"expiry_mm":
	{
		"fields": [ "expmonth", "expimonth", "ccmonth", "ccexpmonth", "ccexpiremonth", "expiry_date_f", "newcreditcardmonth", "selexpmonth", "cardmonth", "cc_expdate_month", "ccmo", "expiration_month1", "expirationmonth", "1.28.9.5.5.1.0.13.3.1.28", "creditcard.exp.month", "cc_exp_month", "cds_cc_exp_month", "ccexp", "expirymonth", "cmbmonth", "paymentinfo[thrumonth]", "card_exp_mo", "expmo", "Ecom_Payment_Card_ExpDate_Month", "billing[month]" ], 
		"+labels": [ "Expiration", "Expiration Date", "Expiration date", "Credit card expiry date (MM/YYYY)", "Expiry Date", "EXPIRY DATE", "Expires", "Expire fin", "Ablaufmonat" ], 
		"-labels": [ "Issued", "Valid From", "Start Date" ], 
		"values":[ "11", "12 - Dec", "12 - December", "11-November", "Jan", "Oct (10)", "January", "jan", "Январь", "январь", "Januar", "janvier", "janv.", "enero", "gennaio", "November (11)" ],
		"types": "ST",
		"minLength": 2,
		"maxLength": 2
	},
	
	"expiry_yy":
	{
		"fields": [ "expyear", "expiyear", "ccexpyear", "ccexpireyear", "expirationyear", "ccyear", "newcreditcardyear", "selexpyear", "cardyear", "cc_expdate_year", "ccyr", "expiration_year1", "1.28.9.5.5.1.0.13.3.1.30", "creditcard.exp.year" , "cc_exp_year", "cds_cc_exp_year", "expiryyear", "cmbyear", "paymentinfo[thruyear]", "card_exp_yr", "expyr", "Ecom_Payment_Card_ExpDate_Year", "billing[year]" ], 
		"+labels": [ "Expiration Year", "/" ], 
		"values": [ "2013", "14" ],
		"-values": [ "2005", "1", "2", "3", "60" ],
		"types": "ST",
		"minLength": 2,
		"maxLength": 4
	},
	
	"validFrom_mm":
	{
		"fields": [ "frommonth", "paymentinfo[frommonth]", "startmonth", "startmo", "Ecom_Payment_Card_ValidFrom_Month" ], 
		"+labels": [ "Date Valid From", "Issued", "Start Date" ], 
		"-labels": [ "Expiration Date", "Expiration date", "Expiry Date", "EXPIRY DATE", "Expires", "Expire fin", "Ablaufmonat" ], 
		"values":[ "11", "12 - Dec", "12 - December", "11-November", "Jan", "Oct (10)", "January", "jan", "Январь", "январь", "Januar", "janvier", "janv.", "enero", "gennaio", "DEZ" ],
		"types": "ST",
		"minLength": 2,
		"maxLength": 2
	},
	
	"validFrom_yy":
	{
		"fields": [ "fromyear", "paymentinfo[fromyear]", "startyear", "startyr", "Ecom_Payment_Card_ValidFrom_Year" ], 
		"+labels": [ "From Year", "Issued Year" ], 
		"values": [ "2006" ],
		"types": "ST",
		"minLength": 2,
		"maxLength": 4
	},
	
	"cvv": 
	{
		"fields": [ "cvv2", "ccv2", "cvc2", "cvv", "ccv", "cvs", "csc", "cccvv2", "verify_credit_card", "cvv2_number", "cccvc", "ccvnc", "cc_security_code1", "1.28.9.5.5.1.0.13.3.1.32.1", "1.28.9.5.5.1.0.13.5.1.32.1", "1.26.9.5.5.1.0.13.5.1.30.1", "securitycodefield", "ccvernbr", "creditcard.cvv", "cardcvv", "ccsec", "creditcard:cvn", "txtcvc2", "cccsc", "customer/card/securityid", "cccid", "creditcard.cvn", "kontrol", "cardverificationcode", "cardcvm", "ccode", "card_verification", "Ecom_Payment_Card_Verification", "credit_cvv", "cardsec" ], 
		"+labels": [ "Credit Card Security ID", "CVV2 Number", "Security Code", "Security code", "security code", "Credit card security code", "Security Digits", "CVS Code", "CVV Code", "CVV", "Card ID Number", "Verification Code", "Card Verification Code", "Enter security code", "Card Verification", "Card Identification Number", "CVV2", "V-Code", "CVC", "CSC", "Card Verification Number", "CID Number", "CID", "Cryptogramme de sécurité", "Cvc", "Checksumme", "Verifikationskode", "Sicherheitskode", "kontrolciffer", "Kontrolcifre", "Card Security Value", "Card code", "Signature Panel Code", "Card Validation Number", "CVV / Card ID", "Card ID", "CVD Number", "Security Digits", "CVV/CV2" ], 
		"types": "TP",
		"minLength": 3,
		"maxLength": 5
	},
	
	"issuenumber" :
	{
		"fields": [ "paymentinfo[cardissuenumber]", "issue_number_f", "issuenum", "Ecom_Payment_Card_IssueNumber" ],
		"+labels": [ "Issue Number" ],
		"types": "T",
		"minLength": 5,
		"maxLength": 6
	}
}
